package #
Date::Manip::Offset::off076;
# Copyright (c) 2008-2015 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'tzdata' is run.
#    Generated on: Wed Nov 25 11:44:43 EST 2015
#    Data version: tzdata2015g
#    Code version: tzcode2015g

# This module contains data from the zoneinfo time zone database.  The original
# data was obtained from the URL:
#    ftp://ftp.iana.org/tz

use strict;
use warnings;
require 5.010000;

our ($VERSION);
$VERSION='6.52';
END { undef $VERSION; }

our ($Offset,%Offset);
END {
   undef $Offset;
   undef %Offset;
}

$Offset        = '+03:00:00';

%Offset        = (
   0 => [
      'asia/baghdad',
      'africa/nairobi',
      'europe/minsk',
      'europe/kaliningrad',
      'asia/riyadh',
      'antarctica/syowa',
      'asia/qatar',
      'africa/khartoum',
      'etc/gmt+3',
      'p',
      'europe/moscow',
      'europe/samara',
      'europe/volgograd',
      'asia/tbilisi',
      'europe/simferopol',
      'asia/yerevan',
      'asia/baku',
      'europe/zaporozhye',
      'europe/vilnius',
      'europe/kiev',
      'europe/chisinau',
      'europe/uzhgorod',
      'europe/riga',
      'europe/tallinn',
      'europe/istanbul',
      ],
   1 => [
      'eet',
      'europe/istanbul',
      'asia/beirut',
      'asia/damascus',
      'europe/athens',
      'europe/bucharest',
      'europe/chisinau',
      'asia/gaza',
      'asia/jerusalem',
      'asia/hebron',
      'europe/helsinki',
      'asia/amman',
      'asia/nicosia',
      'europe/sofia',
      'europe/riga',
      'europe/tallinn',
      'europe/vilnius',
      'europe/zaporozhye',
      'europe/kiev',
      'europe/simferopol',
      'europe/uzhgorod',
      'africa/cairo',
      'europe/kaliningrad',
      'europe/minsk',
      'europe/moscow',
      'europe/samara',
      'africa/khartoum',
      'europe/berlin',
      'africa/johannesburg',
      'africa/windhoek',
      'europe/warsaw',
      ],
);

1;
